@@ -30,12 +30,13 @@
 #include <config.h>
 
 #include "rcsid.h"
-RCSID("$Id: chowntty.c,v 1.1 2000/12/17 05:34:11 tom Exp $")
+RCSID("$Id: chowntty.c,v 1.2 2003/05/16 08:27:42 tom Exp $")
 
 #include <sys/types.h>
 #include <sys/stat.h>
 
 #include <stdio.h>
+#include <errno.h>
 #include <grp.h>
 
 #include "prototypes.h"
@@ -72,7 +73,6 @@ chown_tty(tty, info)
 	const char *tty;
 	const struct passwd *info;
 {
-	extern	int	errno;
 	char	buf[BUFSIZ];
 	char	*group;		/* TTY group name or number */
 	struct	group	*grent;
