@@ -6,7 +6,7 @@
  +----------------------------------------------------------------------------*/
 
 /*
- * Copyright (c) 1997-1999  The Stanford SRP Authentication Project
+ * Copyright (c) 1997-2007  The Stanford SRP Authentication Project
  * All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -30,23 +30,16 @@
  * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
  * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * In addition, the following conditions apply:
- *
- * 1. Any software that incorporates the SRP authentication technology
- *    must display the following acknowlegment:
- *    "This product uses the 'Secure Remote Password' cryptographic
- *     authentication system developed by Tom Wu (tjw@CS.Stanford.EDU)."
- *
- * 2. Any software that incorporates all or part of the SRP distribution
- *    itself must also display the following acknowledgment:
- *    "This product includes software developed by Tom Wu and Eugene
- *     Jhong for the SRP Distribution (http://srp.stanford.edu/srp/)."
- *
- * 3. Redistributions in source or binary form must retain an intact copy
- *    of this copyright notice and list of conditions.
+ * Redistributions in source or binary form must retain an intact copy
+ * of this copyright notice.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #ifdef SRP
+#undef SRP /* unfortunately this clashes with libsrp/srp.h */
 
 #include <stdio.h>
 #include <string.h>
@@ -55,19 +48,11 @@
 #include <netinet/in.h>
 #include "pwd.h"
 #include "t_pwd.h"
-#include "t_client.h"
+#include "srp.h"
 #include "krypto.h"
 
 #define SRP_PROT_VERSION 	1
 
-#ifndef NOENCRYPTION
-#define SRP_DEFAULT_CIPHER 	CIPHER_ID_CAST5_CBC
-#else
-#define SRP_DEFAULT_CIPHER 	CIPHER_ID_NONE
-#endif
-
-#define SRP_DEFAULT_HASH 	HASH_ID_SHA
-
 char srp_user[BUFSIZ];
 char *srp_pass;
 char *srp_acct;
@@ -75,8 +60,8 @@ char *srp_acct;
 unsigned char srp_pref_cipher = 0;
 unsigned char srp_pref_hash = 0;
 
-static struct t_client *tc = NULL;
-static unsigned char *skey = NULL;
+SRP *ctx = NULL;
+static cstr *skey = NULL;
 static krypto_context *incrypt = NULL;
 static krypto_context *outcrypt = NULL;
 
@@ -190,8 +175,8 @@ int srp_userpass (host)
  +--------------------------------------------------------------*/
 int srp_reset ()
 {
-  if (tc)
-  { t_clientclose (tc); tc = NULL; }
+  if (ctx)
+  { SRP_free(ctx); ctx = NULL; }
   if (incrypt)
   { krypto_delete (incrypt); incrypt = NULL; }
   if (outcrypt)
@@ -206,7 +191,8 @@ char *host;
 char *user;
 char *pass;
 {
-  struct t_num *wp;
+  cstr *wp = NULL;
+  cstr *resp = NULL;
   struct t_num N;
   struct t_num g;
   struct t_num s;
@@ -280,18 +266,35 @@ char *pass;
     if (srp_get (&bp, &(g.data), &blen, &(g.len)) < 0) goto data_error;
     if (srp_get (&bp, &(s.data), &blen, &(s.len)) < 0) goto data_error;
 
-    if ((tc = t_clientopen (srp_user, &N, &g, &s)) == NULL)
+    if ((ctx = SRP_new(SRP_RFC2945_client_method())) == NULL)
     {
-      fprintf (stderr, "Unable to open SRP client structure.\n");
+      fprintf (stderr, "Unable to initialize SRP context.\n");
       goto bad;
     }
 
-    wp = t_clientgenexp (tc);
+    if (SRP_set_username(ctx, srp_user) != SRP_SUCCESS)
+    {
+      fprintf (stderr, "Error initializing SRP username.\n");
+      goto bad;
+    }
+
+    if (SRP_set_params(ctx, N.data, N.len, g.data, g.len, s.data, s.len) != SRP_SUCCESS)
+    {
+      fprintf (stderr, "Error initializing SRP parameters.\n");
+      goto bad;
+    }
+
+    if(SRP_gen_pub(ctx, &wp) != SRP_SUCCESS)
+    {
+      fprintf (stderr, "Error generating SRP public value.\n");
+      goto bad;
+    }
 
     /* send wp */
 
     bp = tmp; blen = 0;
-    srp_put (wp->data, &bp, wp->len, &blen);
+    srp_put (wp->data, &bp, wp->length, &blen);
+    cstr_free(wp);
     if (e = radix_encode (tmp, buf, &blen, 0)) goto encode_error;
 
     reply_parse = "ADAT=";
@@ -309,15 +312,30 @@ char *pass;
     if (srp_get (&bp, &(yp.data), &blen, &(yp.len)) < 0) goto data_error;
 
     if (!srp_pass) srp_pass = mygetpass ("SRP Password:");
-    t_clientpasswd (tc, srp_pass);
+    if(SRP_set_auth_password(ctx, srp_pass) != SRP_SUCCESS)
+    {
+      fprintf (stderr, "Error setting SRP password.\n");
+      goto bad;
+    }
+
     memset (srp_pass, 0, strlen (srp_pass));
 
-    skey = t_clientgetkey (tc, &yp);
+    if(SRP_compute_key(ctx, &skey, yp.data, yp.len) != SRP_SUCCESS)
+    {
+      fprintf (stderr, "Error computing SRP session key.\n");
+      goto bad;
+    }
 
     /* send response */
 
     bp = tmp; blen = 0;
-    srp_put (t_clientresponse (tc), &bp, 20, &blen);
+    if(SRP_respond(ctx, &resp) != SRP_SUCCESS)
+    {
+      fprintf (stderr, "Error computing SRP client response.\n");
+      goto bad;
+    }
+    srp_put (resp->data, &bp, resp->length, &blen);
+    cstr_free(resp);
     if (e = radix_encode (tmp, buf, &blen, 0)) goto encode_error;
 
     reply_parse = "ADAT=";
@@ -334,7 +352,7 @@ char *pass;
     if (e = radix_encode (reply_parse, bp, &blen, 1)) goto encode_error;
     if (srp_get (&bp, &cp, &blen, &clen) != 20) goto data_error;
 
-    if (t_clientverify (tc, cp))
+    if (SRP_verify(ctx, cp, 20) != SRP_SUCCESS)
     {
       fprintf (stderr, "WARNING: bad response to client challenge.\n");
       goto bad;
@@ -374,8 +392,10 @@ char *pass;
     if (cipher_supported (clist, srp_pref_cipher))
       cid = srp_pref_cipher;
 
+    /*
     if (!cid && cipher_supported (clist, SRP_DEFAULT_CIPHER))
       cid = SRP_DEFAULT_CIPHER;
+    */
 
     if (!cid)
     {
@@ -392,8 +412,10 @@ char *pass;
     if (srp_pref_hash && hash_supported (hlist, srp_pref_hash))
       hid = srp_pref_hash;
 
+    /*
     if (!hid && hash_supported (hlist, SRP_DEFAULT_HASH))
       hid = SRP_DEFAULT_HASH;
+    */
 
     if (!hid)
     {
@@ -407,7 +429,7 @@ char *pass;
 
     /* set incrypt */
 
-    if (!(incrypt = krypto_new (cid, hid, skey, 20, NULL, 0, seqnum,
+    if (!(incrypt = krypto_new (cid, hid, skey->data, 20, NULL, 0, seqnum,
          KRYPTO_DECODE)))
       goto bad;
 
@@ -428,11 +450,11 @@ char *pass;
 
     /* set outcrypt */
 
-    if (!(outcrypt = krypto_new (cid, hid, skey+20, 20, NULL, 0, seqnum,
+    if (!(outcrypt = krypto_new (cid, hid, skey->data+20, 20, NULL, 0, seqnum,
          KRYPTO_ENCODE)))
       goto bad;
 
-    t_clientclose (tc); tc = NULL;
+    SRP_free(ctx); ctx = NULL;
   }
 
   if (n != COMPLETE) goto bad;
