@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003  The Stanford SRP Authentication Project
+ * Copyright (c) 1997-2007  The Stanford SRP Authentication Project
  * All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -23,20 +23,8 @@
  * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
  * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * In addition, the following conditions apply:
- *
- * 1. Any software that incorporates the SRP authentication technology
- *    is requested to display the following acknowlegment:
- *    "This product uses the 'Secure Remote Password' cryptographic
- *     authentication system developed by Tom Wu (tjw@CS.Stanford.EDU)."
- *
- * 2. Any software that incorporates all or part of the SRP distribution
- *    itself must display the following acknowledgment:
- *    "This product includes software developed by Tom Wu and Eugene
- *     Jhong for the SRP Distribution (http://srp.stanford.edu/)."
- *
- * 3. Redistributions in source or binary form must retain an intact copy
- *    of this copyright notice and list of conditions.
+ * Redistributions in source or binary form must retain an intact copy
+ * of this copyright notice.
  */
 #include "t_defines.h"
 #include "srp.h"
@@ -62,6 +50,7 @@ static SRP_RESULT
 srp2945_client_init(SRP * srp)
 {
   srp->magic = SRP_MAGIC_CLIENT;
+  srp->param_cb = SRP_CLIENT_default_param_verify_cb;
   srp->meth_data = malloc(sizeof(struct client_meth_st));
   SHA1Init(&CLIENT_CTXP(srp)->hash);
   SHA1Init(&CLIENT_CTXP(srp)->ckhash);
