@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2001  The Stanford SRP Authentication Project
+ * Copyright (c) 1997-2007  The Stanford SRP Authentication Project
  * All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -23,20 +23,8 @@
  * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
  * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * In addition, the following conditions apply:
- *
- * 1. Any software that incorporates the SRP authentication technology
- *    is requested to display the following acknowlegment:
- *    "This product uses the 'Secure Remote Password' cryptographic
- *     authentication system developed by Tom Wu (tjw@CS.Stanford.EDU)."
- *
- * 2. Any software that incorporates all or part of the SRP distribution
- *    itself must display the following acknowledgment:
- *    "This product includes software developed by Tom Wu and Eugene
- *     Jhong for the SRP Distribution (http://srp.stanford.edu/)."
- *
- * 3. Redistributions in source or binary form must retain an intact copy
- *    of this copyright notice and list of conditions.
+ * Redistributions in source or binary form must retain an intact copy
+ * of this copyright notice.
  */
 
 #ifdef HAVE_UNISTD_H
@@ -46,10 +34,11 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "srp_aux.h"
 #include "t_pwd.h"
 
 #define MIN_BASIS_BITS 512
-#define BASIS_BITS 2048
+#define MAX_BASIS_BITS 4096
 
 extern int  optind;
 extern char *optarg;
@@ -62,6 +51,33 @@ int  debug   = 0;
 int  verbose = 0;
 int  composite = 0;
 
+void
+print_num(const unsigned char * data, int sz, int radix, int oneline)
+{
+  cstr * buf = cstr_new();
+  BigInteger b = BigIntegerFromBytes(data, sz);
+
+  if(radix >= 10) {
+    cstr_set_length(buf, sz * 2 + 1);
+    BigIntegerToString(b, buf->data, buf->length, radix);
+    if(oneline && strlen(buf->data) > 60) {
+      printf("%.30s ... %.30s", buf->data, buf->data + strlen(buf->data) - 30);
+    }
+    else
+      printf("%s", buf->data);
+  }
+  BigIntegerFree(b);
+  cstr_free(buf);
+}
+
+void
+usage()
+{
+  /* TODO: explain options */
+  fprintf(stderr, "usage: %s [-dvfx2] [-c configfile]\n", progName);
+  exit(1);
+}
+
 int main(argc, argv)
      int argc;
      char *argv[];
@@ -69,8 +85,9 @@ int main(argc, argv)
   char *chp;
   char *configFile = NULL;
   char cbuf[256];
-  char b64buf[MAXB64PARAMLEN];
-  int c, ch, i, lastidx, keylen, yesno, fsize, status, nparams;
+  int c, ch, i, lastidx, keylen, yesno, fsize, nparams;
+  int radix = 64;
+  int oneline = 1;
   FILE *efp;
 
   struct t_preconf * tpc;
@@ -78,9 +95,11 @@ int main(argc, argv)
   struct t_confent * tcent;
 
   progName = *argv;
+#ifndef WIN32
   if ((chp = strrchr(progName, '/')) != (char *) 0) progName = chp + 1;
+#endif
 
-  while ((ch = getopt(argc, argv, "dv2c:")) != EOF)
+  while ((ch = getopt(argc, argv, "dvfx2c:")) != EOF)
     switch(ch) {
     case 'c':
       configFile = optarg;
@@ -91,12 +110,17 @@ int main(argc, argv)
     case 'd':
       debug++;
       break;
+    case 'x':
+      radix = 16;
+      break;
+    case 'f':
+      oneline = 0;
+      break;
     case '2':
       composite++;
       break;
     default:
-      fprintf(stderr, "usage: %s [-dv2] [-c configfile]\n", progName);
-      exit(1);
+      usage();
     }
 
   argc -= optind;
@@ -106,14 +130,14 @@ int main(argc, argv)
      configFile = DEFAULT_CONF;
 
   efp = fopen(configFile, "a+");
-  if(efp == NULL)
+  if(efp == NULL) {
     if(creat(configFile, 0644) < 0 || (efp = fopen(configFile, "a+")) == NULL) {
-      fprintf(stderr, "%s: unable to create %s (errno = %d)\n",
-	      progName, configFile, errno);
+      perror(configFile);
       exit(2);
     }
     else
       printf("%s: Creating new configuration file %s\n", progName, configFile);
+  }
 
   tc = t_openconf(efp);
   if(tc == NULL) {
@@ -133,12 +157,14 @@ int main(argc, argv)
     printf("Current field size is %d bits.\n", keylen);
     printf("\nIncrease the default field size? [y] ");
     yesno = 0;
-    while((c = getchar()) != '\n' && c != EOF)
-      if(yesno == 0)
+    while((c = getchar()) != '\n' && c != EOF) {
+      if(yesno == 0) {
 	if(c == 'n' || c == 'N')
 	  yesno = -1;
 	else if(c == 'y' || c == 'Y')
 	  yesno = 1;
+      }
+    }
     if(c == EOF || yesno < 0)
       exit(0);
   }
@@ -164,10 +190,13 @@ int main(argc, argv)
     nparams = t_getprecount();
     for(i = 0; i < nparams; ++i) {
       tpc = t_getpreparam(i);
-      printf("(%d) [%d bits]  %s\n    Modulus = %s\n  Generator = %s\n",
+      printf("(%d) [%d bits]  %s\n    Modulus = ",
 	     i + 1, 8 * tpc->modulus.len,
-	     tpc->comment ? tpc->comment : "",
-	     tpc->mod_b64, tpc->gen_b64);
+	     tpc->comment ? tpc->comment : "");
+      print_num(tpc->modulus.data, tpc->modulus.len, radix, oneline);
+      printf("\n  Generator = ");
+      print_num(tpc->generator.data, tpc->generator.len, radix, oneline);
+      printf("\n");
     }
     printf("\nSelect a field (1-%d): ", nparams);
     fgets(cbuf, sizeof(cbuf), stdin);
@@ -179,9 +208,9 @@ int main(argc, argv)
     tcent->index = lastidx + 1;
     tpc = t_getpreparam(i - 1);
     tcent->modulus.len = tpc->modulus.len;
-    memcpy(tcent->modulus.data, tpc->modulus.data, tpc->modulus.len);
+    tcent->modulus.data = tpc->modulus.data;
     tcent->generator.len = tpc->generator.len;
-    memcpy(tcent->generator.data, tpc->generator.data, tpc->generator.len);
+    tcent->generator.data = tpc->generator.data;
     t_putconfent(tcent, efp);
     t_closeconf(tc);
     fclose(efp);
@@ -194,14 +223,15 @@ int main(argc, argv)
   printf(" 768 (moderate security)\n");
   printf("1024 (most popular default)\n");
   printf("1536 (additional security, possibly slow)\n");
-  printf("2048 (maximum supported security level)\n");
-  printf("\nField size (%d to %d): ", MIN_BASIS_BITS, BASIS_BITS);
+  printf("2048 (maximum supported security level for v1)\n");
+  printf("%d (maximum predefined field length)\n", MAX_BASIS_BITS);
+  printf("\nField size (minimum %d): ", MIN_BASIS_BITS);
 
   fgets(cbuf, sizeof(cbuf), stdin);
   fsize = atoi(cbuf);
-  if(fsize < MIN_BASIS_BITS || fsize > BASIS_BITS) {
-    fprintf(stderr, "%s: field size must be between %d and %d\n",
-	    progName, MIN_BASIS_BITS, BASIS_BITS);
+  if(fsize < MIN_BASIS_BITS) {
+    fprintf(stderr, "%s: field size must be at least %d bits\n",
+	    progName, MIN_BASIS_BITS);
     exit(1);
   }
 
@@ -224,11 +254,11 @@ int main(argc, argv)
     tcent->index = lastidx + 1;
 
     printf("\nParameters successfully generated.\n");
-    printf("N = [%s]\n", t_tob64(b64buf,
-				 tcent->modulus.data, tcent->modulus.len));
-    printf("g = [%s]\n", t_tob64(b64buf,
-				 tcent->generator.data, tcent->generator.len));
-    printf("\nUpdate the configuration file with these parameters? [Ynq] ");
+    printf("N = [");
+    print_num(tcent->modulus.data, tcent->modulus.len, radix, 0);
+    printf("]\ng = [");
+    print_num(tcent->generator.data, tcent->generator.len, radix, 0);
+    printf("]\n\nUpdate the configuration file with these parameters? [Ynq] ");
 
     fgets(cbuf, sizeof(cbuf), stdin);
     switch(*cbuf) {
