@@ -103,7 +103,7 @@ static	int	auth_send_last = -1;
  * in priority order, i.e. try the first one first.
  */
 Authenticator authenticators[] = {
-#ifdef	SRP
+#ifdef	HAVE_SRP
 #  ifdef TLS
     { AUTHTYPE_SRP, AUTH_WHO_CLIENT|AUTH_HOW_ONE_WAY|AUTH_ENCRYPT_START_TLS,
           srp_init,
