@@ -1847,7 +1847,10 @@ static int envvarok(varp)
 	    strcmp(varp, "SHLIB_PATH") &&
 	    strcmp(varp, "ENV") &&
 	    strcmp(varp, "BASH_ENV") &&
-	    strcmp(varp, "IFS")) {
+	    strcmp(varp, "NLSPATH") && /* locale stuff */
+	    strncmp(varp, "LC_", strlen("LC_")) && /* locale stuff */
+	    strcmp(varp, "IFS") &&
+	    !strchr(varp, '-')) {
 		return 1;
 	} else {
 		syslog(LOG_INFO, "Rejected the attempt to modify the environment variable \"%s\"", varp);
