@@ -533,7 +533,7 @@ getpty(ptynum)
 int *ptynum;
 {
 	register int p = -1;
-#ifdef	STREAMSPTY
+#if defined(STREAMSPTY) || defined(UNIX98_PTY)
 	int t;
 	char *ptsname();
 
@@ -557,7 +557,7 @@ int *ptynum;
 		return(p);
 	}
 
-#else	/* ! STREAMSPTY */
+#else	/* ! STREAMSPTY && ! UNIX98_PTY */
 #ifndef CRAY
 	register char *cp, *p1, *p2;
 	register int i;
@@ -654,7 +654,7 @@ int *ptynum;
 		}
 	}
 #endif	/* CRAY */
-#endif	/* STREAMSPTY */
+#endif	/* STREAMSPTY || UNIX98_PTY */
 	return(-1);
 }
 #endif	/* convex */
@@ -1854,6 +1854,16 @@ start_login(host, autologin, name)
 #endif
 #if	defined (AUTHENTICATION) || defined(TLS)
 	if (auth_level >= 0 && autologin == AUTH_VALID && name[0]) {
+		if (name[0] == '-') {
+		    /* Authenticated and authorized to log in to an
+		       account starting with '-'?  Even if that
+		       unlikely case comes to pass, the current login
+		       program will not parse the resulting command
+		       line properly.  */
+		    syslog(LOG_ERR, "user name cannot start with '-'");
+		    fatal(net, "user name cannot start with '-'");
+		    exit(1);
+		}
 # if	!defined(NO_LOGIN_F)
 #  ifdef LOGIN_CAP_F
 		argv = addarg(argv, "-F");
@@ -1949,7 +1959,14 @@ start_login(host, autologin, name)
 	} else
 #endif
 	if (getenv("USER")) {
-		argv = addarg(argv, getenv("USER"));
+		char *user = getenv("USER");
+		if (user[0] == '-') {
+		    /* "telnet -l-x ..." */
+		    syslog(LOG_ERR, "user name cannot start with '-'");
+		    fatal(net, "user name cannot start with '-'");
+		    exit(1);
+		}
+		argv = addarg(argv, user);
 		/*
 		 * Assume that login will set the USER variable
 		 * correctly.  For SysV systems, this means that
@@ -1968,6 +1985,7 @@ start_login(host, autologin, name)
 
 		argv = addarg(argv, "");	/* no login name */
 		for (p = environ; *p; p++) {
+		    if ((*p)[0] != '-')
 			argv = addarg(argv, *p);
 		}
 	}
@@ -1976,6 +1994,7 @@ start_login(host, autologin, name)
 	{
 		register char **cpp;
 		for (cpp = environ; *cpp; cpp++)
+		    if ((*cpp)[0] != '-')
 			argv = addarg(argv, *cpp);
 	}
 #endif
